######################################
Agilent 8722ES Vector Network Analyzer
######################################

.. autoclass:: pymeasure.instruments.agilent.Agilent8722ES
    :members:
    :show-inheritance: